/* This file is part of the db4o object database http://www.db4o.com

Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com

db4o is free software; you can redistribute it and/or modify it under
the terms of version 3 of the GNU General Public License as published
by the Free Software Foundation.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see http://www.gnu.org/licenses/. */
using System;
using Db4oUnit.Extensions;
using Db4objects.Db4o.Tests.Common.Events;

namespace Db4objects.Db4o.Tests.Common.Events
{
	public class AllTests : ComposibleTestSuite
	{
		public static void Main(string[] args)
		{
			new Db4objects.Db4o.Tests.Common.Events.AllTests().RunAll();
		}

		protected override Type[] TestCases()
		{
			return ComposeTests(new Type[] { typeof(ActivationEventsTestCase), typeof(ClassRegistrationEventsTestCase
				), typeof(CreationEventsTestCase), typeof(DeleteEventOnClientTestCase), typeof(DeletionEventExceptionTestCase
				), typeof(DeletionEventsTestCase), typeof(EventArgsTransactionTestCase), typeof(
				EventCountTestCase), typeof(ExceptionPropagationInEventsTestSuite), typeof(InstantiationEventsTestCase
				), typeof(ObjectContainerEventsTestCase), typeof(ObjectContainerOpenEventTestCase
				), typeof(QueryEventsTestCase), typeof(UpdateInCallbackThrowsTestCase) });
		}

		#if !SILVERLIGHT
		protected override Type[] ComposeWith()
		{
			return new Type[] { typeof(DeleteOnDeletingCallbackTestCase), typeof(OwnCommitCallbackFlaggedNetworkingTestSuite
				) };
		}
		#endif // !SILVERLIGHT
	}
}
